View source: R/precision_profile_methods.R
| summary.precision_profile | R Documentation |
Provides a detailed summary of precision profile results, including fitted values, residuals, fit statistics, and functional sensitivity estimates.
## S3 method for class 'precision_profile'
summary(object, ...)
object |
An object of class |
... |
Additional arguments (currently ignored). |
An object of class summary.precision_profile containing summary
statistics.
# See ?precision_profile for examples
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.