| summary.ate_specs | R Documentation |
Provides a detailed summary of allowable total error specifications, including the formulas used and all three performance tiers for comparison.
## S3 method for class 'ate_specs'
summary(object, ...)
object |
An object of class |
... |
Additional arguments (currently ignored). |
An object of class summary.ate_specs containing detailed
specification information, printed as a side effect.
ate <- ate_from_bv(cvi = 5.6, cvg = 7.5)
summary(ate)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.